@@ -5,6 +5,7 @@ from warnings import warn
 def mk_jwt_middleware(secret, verify=True):
     from aiohttp import web
     import jwt
+
     @web.middleware
     async def middleware(req, handler):
         if handler.__name__ == 'ping' or handler.__name__ == 'openapi':
@@ -17,8 +18,14 @@ def mk_jwt_middleware(secret, verify=True):
             return await handler(req)
         except jwt.DecodeError as error:
             if verify:
-                return web.HTTPUnauthorized(text=json.dumps({'error': f'Invalid authentication token "{token}", {str(error)}'}),
-                                            content_type='application/json')
+                return web.HTTPUnauthorized(
+                    text=json.dumps(
+                        {
+                            'error': f'Invalid authentication token "{token}", {str(error)}'
+                        }
+                    ),
+                    content_type='application/json',
+                )
             warn(f'Invalid JWT: {token}')
             return await handler(req)
 
@@ -27,12 +34,15 @@ def mk_jwt_middleware(secret, verify=True):
 
 def mk_superadmin_middleware(secret):
     from aiohttp import web
+
     @web.middleware
     async def middleware(req, handler):
         auth_header = req.headers.get('Authorization', '')
         if auth_header == secret:
             return await handler(req)
-        return web.HTTPUnauthorized(text=json.dumps({'error': 'invalid API key'}),
-                                    content_type='application/json')
+        return web.HTTPUnauthorized(
+            text=json.dumps({'error': 'invalid API key'}),
+            content_type='application/json',
+        )
 
     return middleware
